@@ -6,7 +6,7 @@
 
 int mosquitto_auth_plugin_version(void)
 {
-	return MOSQ_AUTH_PLUGIN_VERSION;
+	return 4;
 }
 
 int mosquitto_auth_plugin_init(void **user_data, struct mosquitto_opt *auth_opts, int auth_opt_count)
