@@ -38,6 +38,9 @@ int main(int argc, char *argv[])
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("publish-qos1-test", true, &run);
+	if(mosq == NULL){
+		return 1;
+	}
 	mosquitto_int_option(mosq, MOSQ_OPT_PROTOCOL_VERSION, MQTT_PROTOCOL_V5);
 
 	mosquitto_connect_v5_callback_set(mosq, on_connect);
@@ -49,6 +52,7 @@ int main(int argc, char *argv[])
 		mosquitto_loop(mosq, 300, 1);
 	}
 
+	mosquitto_destroy(mosq);
 	mosquitto_lib_cleanup();
 	return run;
 }
